"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.tryGetDirectoriesIn = exports.makeTextWriter = exports.makeTextReader = void 0;
const ts_results_es_1 = require("ts-results-es");
const promises_1 = __importDefault(require("fs/promises"));
const error_type_guards_1 = require("../utils/error-type-guards");
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
function resultifyFsOp(debugLog, op) {
    return new ts_results_es_1.AsyncResult(ts_results_es_1.Result.wrapAsync(op)).mapErr((error) => {
        (0, error_type_guards_1.assertIsNodeError)(error);
        debugLog("fs-operation failed.", error);
        return error;
    });
}
/**
 * Makes a {@link ReadTextFile} function.
 */
function makeTextReader(debugLog) {
    return (path) => resultifyFsOp(debugLog, () => promises_1.default.readFile(path, { encoding: "utf8" }));
}
exports.makeTextReader = makeTextReader;
/**
 * Makes a {@link WriteTextFile} function.
 */
function makeTextWriter(debugLog) {
    return (filePath, content) => {
        const dirPath = path_1.default.dirname(filePath);
        return resultifyFsOp(debugLog, () => fs_extra_1.default.ensureDir(dirPath)).andThen(() => resultifyFsOp(debugLog, () => promises_1.default.writeFile(filePath, content)));
    };
}
exports.makeTextWriter = makeTextWriter;
/**
 * Attempts to get the names of all directories in a directory.
 * @param directoryPath The directories name.
 * @param debugLog Debug-log function.
 * TODO: Convert to service function.
 */
function tryGetDirectoriesIn(directoryPath, debugLog) {
    return resultifyFsOp(debugLog, () => promises_1.default.readdir(directoryPath, { withFileTypes: true }))
        .map((entries) => entries.filter((it) => it.isDirectory()))
        .map((directories) => directories.map((it) => it.name));
}
exports.tryGetDirectoriesIn = tryGetDirectoriesIn;
//# sourceMappingURL=fs-result.js.map