"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeNpmrcSaver = exports.makeNpmrcLoader = exports.makeNpmrcPathFinder = void 0;
const ts_results_es_1 = require("ts-results-es");
const node_os_1 = require("node:os");
const path_1 = __importDefault(require("path"));
const common_errors_1 = require("./common-errors");
/**
 * Makes a {@link FindNpmrcPath} function.
 */
function makeNpmrcPathFinder(getHomePath) {
    return () => getHomePath().map((homePath) => path_1.default.join(homePath, ".npmrc"));
}
exports.makeNpmrcPathFinder = makeNpmrcPathFinder;
/**
 * Makes a {@link LoadNpmrc} function.
 */
function makeNpmrcLoader(readFile) {
    return (path) => readFile(path)
        .map((content) => content.split(node_os_1.EOL))
        .orElse((error) => error.code === "ENOENT" ? (0, ts_results_es_1.Ok)(null) : (0, ts_results_es_1.Err)(new common_errors_1.GenericIOError()));
}
exports.makeNpmrcLoader = makeNpmrcLoader;
/**
 * Makes a {@link SaveNpmrc} function.
 */
function makeNpmrcSaver(writeFile) {
    return (path, npmrc) => {
        const content = npmrc.join(node_os_1.EOL);
        return writeFile(path, content).mapErr(() => new common_errors_1.GenericIOError());
    };
}
exports.makeNpmrcSaver = makeNpmrcSaver;
//# sourceMappingURL=npmrc-io.js.map