"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeProjectVersionLoader = exports.makeProjectVersionParseError = exports.makeProjectVersionMissingError = void 0;
const path_1 = __importDefault(require("path"));
const ts_results_es_1 = require("ts-results-es");
const common_errors_1 = require("../common-errors");
const string_parsing_1 = require("../utils/string-parsing");
const common_errors_2 = require("./common-errors");
function projectVersionTxtPathFor(projectDirPath) {
    return path_1.default.join(projectDirPath, "ProjectSettings", "ProjectVersion.txt");
}
/**
 * Makes a {@link ProjectVersionMissingError} object.
 * @param filePath The path that was searched.
 */
function makeProjectVersionMissingError(filePath) {
    return new common_errors_2.FileMissingError("ProjectVersion.txt", filePath);
}
exports.makeProjectVersionMissingError = makeProjectVersionMissingError;
/**
 * Makes a {@link ProjectVersionParseError} object.
 * @param filePath The path of the file.
 */
function makeProjectVersionParseError(filePath) {
    return new common_errors_1.FileParseError(filePath, "ProjectVersion.txt");
}
exports.makeProjectVersionParseError = makeProjectVersionParseError;
/**
 * Makes a {@link LoadProjectVersion} function.
 */
function makeProjectVersionLoader(readFile) {
    return (projectDirPath) => {
        const filePath = projectVersionTxtPathFor(projectDirPath);
        return readFile(filePath)
            .mapErr((error) => error.code === "ENOENT"
            ? makeProjectVersionMissingError(filePath)
            : new common_errors_2.GenericIOError())
            .andThen(string_parsing_1.tryParseYaml)
            .andThen((content) => {
            if (!(typeof content === "object" &&
                content !== null &&
                "m_EditorVersion" in content &&
                typeof content.m_EditorVersion === "string"))
                return (0, ts_results_es_1.Err)(makeProjectVersionParseError(filePath));
            return (0, ts_results_es_1.Ok)(content.m_EditorVersion);
        });
    };
}
exports.makeProjectVersionLoader = makeProjectVersionLoader;
//# sourceMappingURL=project-version-io.js.map